@@ -21,12 +21,16 @@ Module variables:
  * check_contracts: True to check contracts
 """
 
-__version__ = "0.9"
+import re
+
+__version__ = "0.12.3"
 check_contracts = True
+re_any_tag = re.compile(r"(^[/\\_]|<[^<]*?>|\{[^{]*?\})")
 
 from gaupol.paths import *
 from gaupol.urls import *
 from gaupol import util
+from gaupol import temp
 from gaupol.base import *
 from gaupol import i18n
 from gaupol.errors import *
